import MonthlyAnalysis from 'components/Analysis/MonthlyAnalysis'
import { FluidType } from 'enum/fluid.enum'
import { mount } from 'enzyme'
import { DateTime } from 'luxon'
import React from 'react'
import * as reactRedux from 'react-redux'
import { Provider } from 'react-redux'
import configureStore from 'redux-mock-store'
import { globalStateData } from '../../../tests/__mocks__/globalStateData.mock'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})
jest.mock('services/consumption.service')
jest.mock(
  'components/PerformanceIndicator/FluidPerformanceIndicator',
  () => 'mock-fluid-performance-indicator'
)

const mockStore = configureStore([])

const mockUseSelector = jest.spyOn(reactRedux, 'useSelector')

describe('MonthlyAnalysis component', () => {
  mockUseSelector.mockReturnValue({
    fluidTypes: [FluidType.ELECTRICITY, FluidType.GAS],
  })

  it('should be rendered correctly', () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <MonthlyAnalysis
          analysisDate={DateTime.fromISO('2021-07-01T00:00:00.000Z', {
            zone: 'utc',
          })}
          saveLastScrollPosition={jest.fn()}
          scrollPosition={0}
        />
      </Provider>
    ).getElement()
    expect(wrapper).toMatchSnapshot()
  })
})
