import Button from '@material-ui/core/Button'
import defaultIcon from 'assets/icons/visu/challenge/challengeLocked.svg'
import StyledIcon from 'components/CommonKit/Icon/StyledIcon'
import { Client, useClient } from 'cozy-client'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import { FluidState } from 'enum/fluid.enum'
import { UsageEventType } from 'enum/usageEvent.enum'
import { UserChallenge } from 'models'
import React, { Dispatch, useCallback, useEffect, useState } from 'react'
import { useDispatch, useSelector } from 'react-redux'
import ChallengeService from 'services/challenge.service'
import UsageEventService from 'services/usageEvent.service'
import { AppActionsTypes, AppStore } from 'store'
import { updateUserChallengeList } from 'store/challenge/challenge.actions'
import { getChallengeTitleWithLineReturn, importIconById } from 'utils/utils'
import './challengeCardUnlocked.scss'
import ChallengeNoFluidModal from './ChallengeNoFluidModal'

interface ChallengeCardUnlockedProps {
  userChallenge: UserChallenge
}
const ChallengeCardUnlocked: React.FC<ChallengeCardUnlockedProps> = ({
  userChallenge,
}: ChallengeCardUnlockedProps) => {
  const client: Client = useClient()
  const dispatch = useDispatch<Dispatch<AppActionsTypes>>()
  const { t } = useI18n()

  const [openNoFluidModal, setopenNoFluidModal] = useState(false)
  const { fluidTypes, fluidStatus } = useSelector(
    (state: AppStore) => state.ecolyo.global
  )
  const [challengeIcon, setChallengeIcon] = useState(defaultIcon)
  let statusRequirementOk = false

  const toggleNoFluidModal = useCallback(() => {
    setopenNoFluidModal(prev => !prev)
  }, [])

  fluidStatus.forEach(fluid => {
    if (
      fluid.status !== FluidState.NOT_CONNECTED &&
      fluid.status !== FluidState.KONNECTOR_NOT_FOUND
    ) {
      statusRequirementOk = true
    }
  })

  const launchChallenge = useCallback(async () => {
    if (fluidTypes.length > 0 && statusRequirementOk) {
      const challengeService = new ChallengeService(client)
      const updatedChallenge = await challengeService.startUserChallenge(
        userChallenge
      )
      await UsageEventService.addEvent(client, {
        type: UsageEventType.CHALLENGE_LAUNCH_EVENT,
        target: userChallenge.id,
      })
      dispatch(updateUserChallengeList(updatedChallenge))
    } else {
      return toggleNoFluidModal()
    }
  }, [
    fluidTypes.length,
    statusRequirementOk,
    client,
    userChallenge,
    dispatch,
    toggleNoFluidModal,
  ])

  useEffect(() => {
    async function handleEcogestureIcon() {
      const icon = await importIconById(userChallenge.id, 'challenge')
      if (icon) {
        setChallengeIcon(icon)
      }
    }
    if (userChallenge) {
      handleEcogestureIcon()
    }
  }, [userChallenge])

  return (
    <>
      <div className="cardContent cardUnlocked">
        <span className="challengeTitle">
          {getChallengeTitleWithLineReturn(userChallenge.id)}
        </span>
        <StyledIcon className="challengeIcon" icon={challengeIcon} />
        <Button
          aria-label={t('challenge.accessibility.button_launch')}
          onClick={launchChallenge}
          classes={{
            root: 'btn-duel-active',
            label: 'text-16-bold',
          }}
        >
          {t('challenge.card_unlocked.button_launch')}
        </Button>
      </div>
      <ChallengeNoFluidModal
        open={openNoFluidModal}
        handleCloseClick={toggleNoFluidModal}
      />
    </>
  )
}

export default ChallengeCardUnlocked
