import { Button } from '@material-ui/core'
import { FluidType } from 'enum/fluid.enum'
import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import React from 'react'
import * as reactRedux from 'react-redux'
import { Provider } from 'react-redux'
import configureStore from 'redux-mock-store'
import { fluidStatusConnectedData } from '../../../tests/__mocks__/fluidStatusData.mock'
import { globalStateData } from '../../../tests/__mocks__/globalStateData.mock'
import ExpiredConsentModal from './ExpiredConsentModal'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})
const mockedNavigate = jest.fn()
jest.mock('react-router-dom', () => ({
  ...jest.requireActual('react-router-dom'),
  useNavigate: () => mockedNavigate,
}))
const mockToggleModal = jest.fn()
const mockHandleCloseClick = jest.fn()

const mockStore = configureStore([])
describe('ExpiredConsentModal component', () => {
  const store = mockStore({
    ecolyo: {
      global: globalStateData,
    },
  })
  beforeEach(() => {
    mockedNavigate.mockReset()
  })
  it('should be rendered correctly', () => {
    const component = mount(
      <Provider store={store}>
        <ExpiredConsentModal
          open={true}
          handleCloseClick={jest.fn()}
          fluidType={FluidType.ELECTRICITY}
          toggleModal={mockToggleModal}
        />
      </Provider>
    )
    expect(toJson(component)).toMatchSnapshot()
  })
  it('should launch the update consent process for GRDF', () => {
    const useDispatchSpy = jest.spyOn(reactRedux, 'useDispatch')
    useDispatchSpy.mockReturnValue(jest.fn())

    const component = mount(
      <Provider store={store}>
        <ExpiredConsentModal
          open={true}
          handleCloseClick={jest.fn()}
          fluidType={FluidType.GAS}
          toggleModal={mockToggleModal}
        />
      </Provider>
    )
    component.find(Button).at(1).simulate('click')
    expect(useDispatchSpy).toHaveBeenCalledTimes(1)
    expect(mockedNavigate).toHaveBeenCalledTimes(1)
  })
  it('should launch the update consent process for Enedis', () => {
    const useDispatchSpy = jest.spyOn(reactRedux, 'useDispatch')
    useDispatchSpy.mockReturnValue(jest.fn())
    const useSelectorSpy = jest.spyOn(reactRedux, 'useSelector')
    useSelectorSpy.mockReturnValue({ fluidStatus: fluidStatusConnectedData })
    const component = mount(
      <Provider store={store}>
        <ExpiredConsentModal
          open={true}
          handleCloseClick={jest.fn()}
          fluidType={FluidType.ELECTRICITY}
          toggleModal={mockToggleModal}
        />
      </Provider>
    )
    component.find(Button).at(1).simulate('click')
    expect(useDispatchSpy).toHaveBeenCalledTimes(2)
    expect(mockedNavigate).toHaveBeenCalledTimes(1)
  })
  it('should click on close modal', () => {
    const component = mount(
      <Provider store={store}>
        <ExpiredConsentModal
          open={true}
          handleCloseClick={mockHandleCloseClick}
          fluidType={FluidType.ELECTRICITY}
          toggleModal={mockToggleModal}
        />
      </Provider>
    )
    component.find(Button).at(0).simulate('click')
    expect(mockHandleCloseClick).toHaveBeenCalled()
  })
})
