import { Button, MenuItem } from '@material-ui/core'
import EcogestureList from 'components/Ecogesture/EcogestureList'
import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import React from 'react'
import { Provider } from 'react-redux'
import { BrowserRouter } from 'react-router-dom'
import configureStore from 'redux-mock-store'
import { challengeStateData } from '../../../tests/__mocks__/challengeStateData.mock'
import { ecogesturesData } from '../../../tests/__mocks__/ecogesturesData.mock'
import { globalStateData } from '../../../tests/__mocks__/globalStateData.mock'
import { waitForComponentToPaint } from '../../../tests/__mocks__/testUtils'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})
jest.mock('components/Ecogesture/EcogestureCard', () => 'mock-ecogesturecard')

const mockStore = configureStore([])
const mockHandleReinit = jest.fn()

describe('EcogesturesList component', () => {
  it('should be rendered correctly', async () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
        challenge: challengeStateData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <BrowserRouter>
          <EcogestureList
            list={ecogesturesData}
            displaySelection={false}
            selectionTotal={0}
            selectionViewed={0}
            handleReinitClick={mockHandleReinit}
          />
        </BrowserRouter>
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(toJson(wrapper)).toMatchSnapshot()
  })

  it('should open the filter menu and select all ecogesture', async () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
        challenge: challengeStateData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <BrowserRouter>
          <EcogestureList
            list={ecogesturesData}
            displaySelection={false}
            selectionTotal={0}
            selectionViewed={0}
          />
        </BrowserRouter>
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    wrapper.find('.filter-button').simulate('click')
    wrapper.find(Button).first().simulate('click')
    expect(wrapper.find('.filter-menu').exists()).toBeTruthy()
    wrapper.find(MenuItem).at(1).simulate('click')
    expect(wrapper.find('.ecogestures').text()).toBe('ecogesture.HEATING')
  })

  it('should display the selection section', async () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
        challenge: challengeStateData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <BrowserRouter>
          <EcogestureList
            list={ecogesturesData}
            displaySelection={true}
            selectionTotal={50}
            selectionViewed={10}
          />
        </BrowserRouter>
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(wrapper.find('.selection').exists()).toBeTruthy()
  })
})
