import { Button, IconButton } from '@material-ui/core'
import Dialog from '@material-ui/core/Dialog'
import CloseIcon from 'assets/icons/ico/close.svg'
import warningIcon from 'assets/icons/ico/warn-orange.svg'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import Icon from 'cozy-ui/transpiled/react/Icon'
import React from 'react'
import './ecogestureReinitModal.scss'
interface EcogestureReinitModalProps {
  open: boolean
  handleCloseClick: () => void
  handleLaunchReinit: () => void
}
const EcogestureReinitModal: React.FC<EcogestureReinitModalProps> = ({
  open,
  handleCloseClick,
  handleLaunchReinit,
}: EcogestureReinitModalProps) => {
  const { t } = useI18n()
  return (
    <Dialog
      open={open}
      onClose={handleCloseClick}
      aria-labelledby={'accessibility-title'}
      classes={{
        root: 'modal-root',
        paper: 'modal-paper',
      }}
    >
      <div id={'accessibility-title'}>
        {t('feedback.accessibility.window_title')}
      </div>
      <IconButton
        aria-label={t('feedback.accessibility.button_close')}
        className="modal-paper-close-button"
        onClick={handleCloseClick}
      >
        <Icon icon={CloseIcon} size={16} />
      </IconButton>
      <div className="eg-reinit-modal">
        <Icon icon={warningIcon} size={63} />
        <div className="title text-20-bold">
          {t('ecogesture.reinitModal.title_part1')}
          <span className="warn-title">
            {t('ecogesture.reinitModal.title_part2')}
          </span>
          {t('ecogesture.reinitModal.title_part3')}
          <span className="warn-title">
            {t('ecogesture.reinitModal.title_part4')}
          </span>
          {t('ecogesture.reinitModal.title_part5')}
          <span className="warn-title">
            {t('ecogesture.reinitModal.title_part6')}
          </span>
        </div>
        <div className="text-16-normal text">
          {t('ecogesture.reinitModal.text1')}
        </div>
        <div className="text-16-bold text">
          {t('ecogesture.reinitModal.text2')}
        </div>
        <div className="buttons-container">
          <Button
            aria-label={t('ecogesture.reinitModal.btn1')}
            onClick={handleCloseClick}
            className="btn1"
            classes={{
              root: 'btn-secondary-negative',
              label: 'text-16-bold',
            }}
          >
            {t('ecogesture.reinitModal.btn1')}
          </Button>
          <Button
            aria-label={t('ecogesture.reinitModal.btn2')}
            onClick={handleLaunchReinit}
            classes={{
              root: 'btn-profile-next rounded',
              label: 'text-16-bold',
            }}
          >
            {t('ecogesture.reinitModal.btn2')}
          </Button>
        </div>
      </div>
    </Dialog>
  )
}

export default EcogestureReinitModal
