/* eslint-disable react/display-name */
import SingleEcogesture from 'components/Ecogesture/SingleEcogesture'
import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import React from 'react'
import { Provider } from 'react-redux'
import configureStore from 'redux-mock-store'
import { challengeStateData } from '../../../tests/__mocks__/challengeStateData.mock'
import { ecogesturesData } from '../../../tests/__mocks__/ecogesturesData.mock'
import { globalStateData } from '../../../tests/__mocks__/globalStateData.mock'
import { waitForComponentToPaint } from '../../../tests/__mocks__/testUtils'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})
const mockedNavigate = jest.fn()

jest.mock('react-router-dom', () => ({
  ...jest.requireActual('react-router-dom'),
  useNavigate: () => mockedNavigate,
  useParams: () =>
    jest.fn().mockReturnValue({ ecogestureID: 'ECOGESTURE0001' }),
  useLocation: jest.fn().mockReturnValue({
    state: { selectionCompleted: true },
  }),
}))
const mockImportIconById = jest.fn()
jest.mock('utils/utils', () => {
  return {
    importIconById: () => mockImportIconById,
  }
})

jest.mock('components/Ecogesture/EfficiencyRating', () => () => (
  <div id="EfficiencyRating" />
))
jest.mock('components/Header/Header', () => () => <div id="Header" />)
jest.mock('components/Header/CozyBar', () => () => <div id="CozyBar" />)
jest.mock('components/Loader/Loader', () => () => <div id="spinner" />)
// eslint-disable-next-line @typescript-eslint/no-explicit-any
jest.mock('components/Content/Content', () => (props: any) => (
  <div id="content">{props.children}</div>
))

const mockGetEcogesturesByIds = jest.fn()
const mockUpdateEcogesture = jest.fn()
jest.mock('services/ecogesture.service', () => {
  return jest.fn(() => {
    return {
      getEcogesturesByIds: mockGetEcogesturesByIds,
      updateEcogesture: mockUpdateEcogesture,
    }
  })
})

const mockStore = configureStore([])

describe('SingleEcogesture component', () => {
  it('should be rendered correctly', async () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
        challenge: challengeStateData,
      },
    })

    mockGetEcogesturesByIds.mockResolvedValue([ecogesturesData[0]])
    const wrapper = mount(
      <Provider store={store}>
        <SingleEcogesture />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(toJson(wrapper)).toMatchSnapshot()
  })

  it('should change doing status', async () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
        challenge: challengeStateData,
      },
    })

    mockGetEcogesturesByIds.mockResolvedValue([ecogesturesData[0]])
    mockImportIconById.mockReturnValue('')
    const updatedEcogesture = { ...ecogesturesData[0], doing: true }
    mockUpdateEcogesture.mockResolvedValueOnce(updatedEcogesture)
    const wrapper = mount(
      <Provider store={store}>
        <SingleEcogesture />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    wrapper.find('.doing-btn').first().simulate('click')
    await waitForComponentToPaint(wrapper)
    expect(mockUpdateEcogesture).toHaveBeenCalledWith(updatedEcogesture)
  })
  it('should change objective status', async () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
        challenge: challengeStateData,
      },
    })

    mockGetEcogesturesByIds.mockResolvedValue([ecogesturesData[0]])
    mockImportIconById.mockReturnValue('icontest')
    const updatedEcogesture = { ...ecogesturesData[0], objective: true }
    mockUpdateEcogesture.mockResolvedValueOnce(updatedEcogesture)

    const wrapper = mount(
      <Provider store={store}>
        <SingleEcogesture />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    wrapper.find('.objective-btn').first().simulate('click')
    await waitForComponentToPaint(wrapper)
    expect(mockUpdateEcogesture).toHaveBeenCalledWith(updatedEcogesture)
  })
  it('should toggle more details', async () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
        challenge: challengeStateData,
      },
    })

    mockGetEcogesturesByIds.mockResolvedValue([ecogesturesData[0]])
    mockImportIconById.mockReturnValue(undefined)

    const wrapper = mount(
      <Provider store={store}>
        <SingleEcogesture />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)

    wrapper.find('.toggle-text').first().simulate('click')
    await waitForComponentToPaint(wrapper)

    expect(wrapper.find('.toggle-text').text()).toBe(
      'ecogesture_modal.show_less'
    )
  })
})
