import { UserExplorationState } from 'enum/userExploration.enum'
import { shallow } from 'enzyme'
import React from 'react'
import * as reactRedux from 'react-redux'
import { challengeStateData } from '../../../tests/__mocks__/challengeStateData.mock'
import { userChallengeData } from '../../../tests/__mocks__/userChallengeData.mock'
import ExplorationError from './ExplorationError'
import ExplorationFinished from './ExplorationFinished'
import ExplorationOngoing from './ExplorationOngoing'
import ExplorationView from './ExplorationView'

jest.mock('components/Header/CozyBar', () => 'mock-cozybar')
jest.mock('components/Header/Header', () => 'mock-header')
jest.mock('components/Content/Content', () => 'mock-content')

const mockUseSelector = jest.spyOn(reactRedux, 'useSelector')

describe('ExplorationView', () => {
  it('should be rendered with ExplorationError component when unknown exploration state', () => {
    const updatedUserChallenge = {
      ...userChallengeData[0],
      exploration: {
        ...userChallengeData[0].exploration,
        state: 99,
      },
    }
    const updatedChallengeState = {
      ...challengeStateData,
      currentChallenge: updatedUserChallenge,
    }
    mockUseSelector.mockReturnValue(updatedChallengeState)
    const wrapper = shallow(<ExplorationView />)
    expect(wrapper.find(ExplorationError).exists()).toBeTruthy()
  })

  it('should be rendered with ExplorationOngoing component when exploration state = unlocked', () => {
    const updatedUserChallenge = {
      ...userChallengeData[0],
      exploration: {
        ...userChallengeData[0].exploration,
        state: UserExplorationState.UNLOCKED,
      },
    }
    const updatedChallengeState = {
      ...challengeStateData,
      currentChallenge: updatedUserChallenge,
    }
    mockUseSelector.mockReturnValue(updatedChallengeState)
    const wrapper = shallow(<ExplorationView />)
    expect(wrapper.find(ExplorationOngoing).exists()).toBeTruthy()
  })

  it('should be rendered with ExplorationOngoing component when exploration state = ongoing', () => {
    const updatedUserChallenge = {
      ...userChallengeData[0],
      exploration: {
        ...userChallengeData[0].exploration,
        state: UserExplorationState.ONGOING,
      },
    }
    const updatedChallengeState = {
      ...challengeStateData,
      currentChallenge: updatedUserChallenge,
    }
    mockUseSelector.mockReturnValue(updatedChallengeState)
    const wrapper = shallow(<ExplorationView />)
    expect(wrapper.find(ExplorationOngoing).exists()).toBeTruthy()
  })

  it('should be rendered with ExplorationFinished component when exploration state = Done', () => {
    const updatedUserChallenge = {
      ...userChallengeData[0],
      exploration: {
        ...userChallengeData[0].exploration,
        state: UserExplorationState.DONE,
      },
    }
    const updatedChallengeState = {
      ...challengeStateData,
      currentChallenge: updatedUserChallenge,
    }
    mockUseSelector.mockReturnValue(updatedChallengeState)
    const wrapper = shallow(<ExplorationView />)
    expect(wrapper.find(ExplorationFinished).exists()).toBeTruthy()
  })
})
