import FeedbackModal from 'components/Feedback/FeedbackModal'
import { mount } from 'enzyme'
import React from 'react'
import { act } from 'react-dom/test-utils'
import * as reactRedux from 'react-redux'
import { Provider } from 'react-redux'
import { BrowserRouter } from 'react-router-dom'
import { createMockEcolyoStore } from '../../../tests/__mocks__/store'
import { userChallengeExplo1OnGoing } from '../../../tests/__mocks__/userChallengeData.mock'

// Value coming from jest.config
declare let __SAU_LINK__: string

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})

jest.mock('services/environment.service', () => {
  return jest.fn(() => {
    return {
      isProduction: () => true,
    }
  })
})

const handleFeedbackModalClose = jest.fn()

const mockUseSelector = jest.spyOn(reactRedux, 'useSelector')
const mockUseDispatch = jest.spyOn(reactRedux, 'useDispatch')

describe('FeedbackModal component', () => {
  const store = createMockEcolyoStore()
  beforeEach(() => {
    store.clearActions()
  })
  it('should render the component', () => {
    mockUseDispatch.mockReturnValue(jest.fn())
    const component = mount(
      <Provider store={store}>
        <BrowserRouter>
          <FeedbackModal
            open={true}
            handleCloseClick={handleFeedbackModalClose}
          />
        </BrowserRouter>
      </Provider>
    ).getElement()
    expect(component).toMatchSnapshot()
  })
})
describe('FeedbackModal functionalities', () => {
  const store = createMockEcolyoStore()
  beforeEach(() => {
    store.clearActions()
  })

  it('should close the modal', async () => {
    mockUseDispatch.mockReturnValue(jest.fn())
    mockUseSelector.mockReturnValue(userChallengeExplo1OnGoing)
    const wrapper = mount(
      <Provider store={store}>
        <BrowserRouter>
          <FeedbackModal
            open={true}
            handleCloseClick={handleFeedbackModalClose}
          />
        </BrowserRouter>
      </Provider>
    )
    await act(async () => {
      await new Promise(resolve => setTimeout(resolve))
      wrapper.update()
    })

    wrapper.find('.modal-paper-close-button').first().simulate('click')
    expect(handleFeedbackModalClose).toHaveBeenCalledTimes(1)
    wrapper.find('.btn-secondary-positive').first().simulate('click')
    expect(handleFeedbackModalClose).toHaveBeenCalledTimes(2)
  })

  it('should open the SAU link', () => {
    global.open = jest.fn()

    const wrapper = mount(
      <Provider store={store}>
        <BrowserRouter>
          <FeedbackModal
            open={true}
            handleCloseClick={handleFeedbackModalClose}
          />
        </BrowserRouter>
      </Provider>
    )
    wrapper.find('.btn-highlight').first().simulate('click')
    expect(window.open).toBeCalledTimes(1)
    expect(global.open).toHaveBeenCalledWith(`${__SAU_LINK__}?version=0.0.0`)
  })
})
