import StyledCard from 'components/CommonKit/Card/StyledCard'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import Icon from 'cozy-ui/transpiled/react/Icon'
import { FluidType } from 'enum/fluid.enum'
import { FluidStatus } from 'models'
import React, { useCallback } from 'react'
import { useSelector } from 'react-redux'
import { useNavigate } from 'react-router-dom'
import { AppStore } from 'store'
import { getAddPicto } from 'utils/picto'
import './konnectorViewerList.scss'

const KonnectorViewerList: React.FC = () => {
  const { t } = useI18n()
  const { fluidStatus } = useSelector((state: AppStore) => state.ecolyo.global)
  const navigate = useNavigate()
  const goToFluid = useCallback(
    fluidType => {
      navigate(`/consumption/${FluidType[fluidType].toLowerCase()}`)
    },
    [navigate]
  )
  return (
    <div className="kv-root">
      <div className="kv-content">
        <div>
          {fluidStatus.map((fluidStatusItem: FluidStatus, key: number) => {
            return (
              <StyledCard
                key={key}
                className="connection-card"
                onClick={() => goToFluid(fluidStatusItem.fluidType)}
              >
                <Icon icon={getAddPicto(fluidStatusItem.fluidType)} size={36} />
                <div
                  className={`konnector-title text-18-bold ${FluidType[
                    fluidStatusItem.fluidType
                  ].toLowerCase()}`}
                >
                  {t(
                    `konnector_options.label_connect_to_${FluidType[
                      fluidStatusItem.fluidType
                    ].toLowerCase()}`
                  )}
                </div>
              </StyledCard>
            )
          })}
        </div>
      </div>
    </div>
  )
}

export default KonnectorViewerList
