import FormNavigation from 'components/FormGlobal/FormNavigation'
import FormProgress from 'components/FormGlobal/FormProgress'
import 'components/ProfileType/profileTypeForm.scss'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import { ProfileTypeStepForm } from 'enum/profileType.enum'
import {
  ProfileType,
  ProfileTypeAnswer,
  ProfileTypeAnswerChoices,
} from 'models/profileType.model'
import React, { useCallback, useEffect, useState } from 'react'

interface ProfileTypeFormNumberSelectionProps {
  step: ProfileTypeStepForm
  viewedStep: ProfileTypeStepForm
  profileType: ProfileType
  answerType: ProfileTypeAnswer
  setNextStep: Function
  setPreviousStep: Function
  isProfileTypeComplete: boolean
}

const ProfileTypeFormNumberSelection: React.FC<
  ProfileTypeFormNumberSelectionProps
> = ({
  step,
  viewedStep,
  profileType,
  answerType,
  setNextStep,
  setPreviousStep,
  isProfileTypeComplete,
}: ProfileTypeFormNumberSelectionProps) => {
  const { t } = useI18n()
  const [answer, setAnswer] = useState<ProfileTypeAnswerChoices>('')
  const [index, setIndex] = useState<number>(0)

  const decrement = () => {
    setAnswer(answerType.choices[index - 1])
    setIndex(prev => prev - 1)
  }

  const increment = () => {
    setAnswer(answerType.choices[index + 1])
    setIndex(prev => prev + 1)
  }

  const handlePrevious = useCallback(() => {
    setPreviousStep(profileType)
  }, [profileType, setPreviousStep])

  const handleNext = useCallback(() => {
    profileType[answerType.attribute] = answer
    setNextStep(profileType)
  }, [profileType, setNextStep, answer, answerType.attribute])

  useEffect(() => {
    if (step < viewedStep || isProfileTypeComplete) {
      const foundIndex = answerType.choices.findIndex(
        element => element && element === profileType[answerType.attribute]
      )
      foundIndex > -1 && setIndex(foundIndex)
      setAnswer(profileType[answerType.attribute])
    } else {
      setAnswer(answerType.choices[0])
    }
  }, [step, viewedStep, profileType, answerType, isProfileTypeComplete])

  return (
    <>
      <div className={'profile-form-container'}>
        <FormProgress step={step} formType={'profile'} />
        <div className={'profile-question-label'}>
          {t(
            `profile_type.${ProfileTypeStepForm[step].toLowerCase()}.question`
          )}
        </div>
        {answer !== null ? (
          <div className={'number-container'}>
            <button
              className={'btn-profile-number'}
              onClick={() => decrement()}
              disabled={index < 1}
            >
              -
            </button>
            <label className={'number'}>
              <input
                type={'text'}
                value={answer}
                name={answerType.attribute}
                disabled={true}
              />
            </label>
            <button
              className={'btn-profile-number'}
              onClick={() => increment()}
              disabled={index >= answerType.choices.length - 1}
            >
              +
            </button>
          </div>
        ) : null}
      </div>
      <FormNavigation
        step={step}
        handlePrevious={handlePrevious}
        handleNext={handleNext}
        disableNextButton={answer === ''}
      />
    </>
  )
}

export default ProfileTypeFormNumberSelection
