import Button from '@material-ui/core/Button'
import quizIcon from 'assets/icons/visu/quiz/questionMark.svg'
import StarsContainer from 'components/Challenge/StarsContainer'
import StyledIcon from 'components/CommonKit/Icon/StyledIcon'
import { Client, useClient } from 'cozy-client'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import { UserChallengeUpdateFlag } from 'enum/userChallenge.enum'
import { UserChallenge } from 'models'
import React, { Dispatch } from 'react'
import { useDispatch } from 'react-redux'
import ChallengeService from 'services/challenge.service'
import { AppActionsTypes } from 'store'
import { updateUserChallengeList } from 'store/challenge/challenge.actions'
import './quizBegin.scss'

interface QuizBeginProps {
  userChallenge: UserChallenge
}

const QuizBegin: React.FC<QuizBeginProps> = ({
  userChallenge,
}: QuizBeginProps) => {
  const client: Client = useClient()
  const { t } = useI18n()
  const dispatch = useDispatch<Dispatch<AppActionsTypes>>()
  const launchQuiz = async () => {
    const challengeService: ChallengeService = new ChallengeService(client)
    const userChallengeUpdated: UserChallenge =
      await challengeService.updateUserChallenge(
        userChallenge,
        UserChallengeUpdateFlag.QUIZ_START
      )
    dispatch(updateUserChallengeList(userChallengeUpdated))
  }

  return (
    <div className="quiz-container">
      <div className="quiz-begin-container">
        <StyledIcon className="quiz-icon" icon={quizIcon} size={180} />
        <StarsContainer
          result={userChallenge.progress.quizProgress}
          isQuizBegin={true}
        />

        <div className="quiz-explanation text-18-bold">
          {t('quiz.explanation')}
        </div>
        <div className="button-start">
          <Button
            aria-label={t('duel.accessibility.button_start_quiz')}
            onClick={launchQuiz}
            classes={{
              root: 'btn-secondary-negative',
              label: 'text-16-normal',
            }}
          >
            {t('duel.button_start')}
          </Button>
        </div>
      </div>
    </div>
  )
}

export default QuizBegin
