import * as Sentry from '@sentry/react'
import { Client } from 'cozy-client'
import logger from 'cozy-logger'
import {
  REMOTE_ORG_ECOLYO_AGENT_PARTNERS_INFO,
  REMOTE_ORG_ECOLYO_AGENT_PARTNERS_INFO_REC,
} from 'doctypes/remote/org.ecolyo.agent.partners.info'
import { PartnersInfo } from 'models/partnersInfo.model'
import logApp from 'utils/logger'
import EnvironmentService from './environment.service'

const logStack = logger.namespace('partnersInfoService')

export default class PartnersInfoService {
  private readonly _client: Client
  constructor(_client: Client) {
    this._client = _client
  }

  /**
   * Get information from backoffice about the status of partners' service
   * On success, respond the partnersInfo
   * Else, throw an error
   */
  public async getPartnersInfo(): Promise<PartnersInfo | undefined> {
    const env = new EnvironmentService()
    const remoteUrl = env.isProduction()
      ? REMOTE_ORG_ECOLYO_AGENT_PARTNERS_INFO
      : REMOTE_ORG_ECOLYO_AGENT_PARTNERS_INFO_REC
    try {
      logApp.info('[Initialization] Getting PartnersInfo')
      const result = await this._client
        .getStackClient()
        .fetchJSON('GET', remoteUrl)
      return result as PartnersInfo
    } catch (error) {
      const errorMessage = `getPartnersInfo: Failed to get partners info: ${JSON.stringify(
        error
      )}`
      logStack('error', errorMessage)
      logApp.error(errorMessage)
      Sentry.captureException(errorMessage)
    }
  }
}
