import { TimeStep } from 'enum/timeStep.enum'
import { DateTime } from 'luxon'
import { defaultAction } from 'store'
import { graphData } from '../../../tests/__mocks__/chartData.mock'
import { mockInitialChartState } from '../../../tests/__mocks__/store'
import {
  SET_CURRENT_DATACHART,
  SET_CURRENT_DATACHART_INDEX,
  SET_CURRENT_INDEX,
  SET_CURRENT_TIMESTEP,
  SET_LOADING,
  SET_SELECTED_DATE,
} from './chart.actions'
import { chartReducer } from './chart.reducer'

describe('chart reducer', () => {
  it('should return the initial state', () => {
    const state = chartReducer(undefined, { ...defaultAction })
    expect(state).toEqual(mockInitialChartState)
  })

  describe('SET_SELECTED_DATE', () => {
    it('should handle SET_SELECTED_DATE with payload', () => {
      const mockDate = DateTime.fromISO('2021-01-01T00:00:00.000Z', {
        zone: 'utc',
      })
      const state = chartReducer(mockInitialChartState, {
        type: SET_SELECTED_DATE,
        payload: mockDate,
      })
      expect(state).toEqual({
        ...mockInitialChartState,
        selectedDate: mockDate,
      })
    })
    it('should handle SET_SELECTED_DATE without payload', () => {
      const state = chartReducer(mockInitialChartState, {
        type: SET_SELECTED_DATE,
      })
      expect(state).toEqual(mockInitialChartState)
    })
  })

  describe('SET_CURRENT_TIMESTEP', () => {
    it('should handle SET_CURRENT_TIMESTEP with payload', () => {
      const state = chartReducer(mockInitialChartState, {
        type: SET_CURRENT_TIMESTEP,
        payload: TimeStep.MONTH,
      })
      expect(state).toEqual({
        ...mockInitialChartState,
        currentTimeStep: TimeStep.MONTH,
      })
    })
    it('should handle SET_CURRENT_TIMESTEP without payload', () => {
      const state = chartReducer(mockInitialChartState, {
        type: SET_CURRENT_TIMESTEP,
      })
      expect(state).toEqual(mockInitialChartState)
    })
  })

  describe('SET_CURRENT_INDEX', () => {
    it('should handle SET_CURRENT_INDEX with payload', () => {
      const state = chartReducer(mockInitialChartState, {
        type: SET_CURRENT_INDEX,
        payload: 1,
      })
      expect(state).toEqual({
        ...mockInitialChartState,
        currentIndex: 1,
      })
    })
    it('should handle SET_CURRENT_INDEX without payload', () => {
      const state = chartReducer(mockInitialChartState, {
        type: SET_CURRENT_INDEX,
      })
      expect(state).toEqual(mockInitialChartState)
    })
  })

  describe('SET_CURRENT_DATACHART', () => {
    it('should handle SET_CURRENT_DATACHART with payload', () => {
      const state = chartReducer(mockInitialChartState, {
        type: SET_CURRENT_DATACHART,
        payload: graphData,
      })
      expect(state).toEqual({
        ...mockInitialChartState,
        currentDatachart: graphData,
      })
    })
    it('should handle SET_CURRENT_DATACHART without payload', () => {
      const state = chartReducer(mockInitialChartState, {
        type: SET_CURRENT_DATACHART,
      })
      expect(state).toEqual(mockInitialChartState)
    })
  })

  describe('SET_CURRENT_DATACHART_INDEX', () => {
    it('should handle SET_CURRENT_DATACHART_INDEX with payload', () => {
      const state = chartReducer(mockInitialChartState, {
        type: SET_CURRENT_DATACHART_INDEX,
        payload: 1,
      })
      expect(state).toEqual({
        ...mockInitialChartState,
        currentDatachartIndex: 1,
      })
    })
    it('should handle SET_CURRENT_DATACHART_INDEX without payload', () => {
      const state = chartReducer(mockInitialChartState, {
        type: SET_CURRENT_DATACHART_INDEX,
      })
      expect(state).toEqual(mockInitialChartState)
    })
  })

  describe('SET_LOADING', () => {
    it('should handle SET_LOADING with payload', () => {
      const state = chartReducer(mockInitialChartState, {
        type: SET_LOADING,
        payload: false,
      })
      expect(state).toEqual({
        ...mockInitialChartState,
        loading: false,
      })
    })
    it('should handle SET_LOADING without payload', () => {
      const state = chartReducer(mockInitialChartState, {
        type: SET_LOADING,
      })
      expect(state).toEqual(mockInitialChartState)
    })
  })
})
