import * as Sentry from '@sentry/react'
import { Client } from 'cozy-client'
import {
  ChallengeState,
  GlobalState,
  ModalState,
  Profile,
  ProfileType,
} from 'models'
import { ChartState } from 'models/chart.model'
import { ProfileEcogesture } from 'models/profileEcogesture.model'
import {
  applyMiddleware,
  combineReducers,
  compose,
  createStore,
  Store,
} from 'redux'
import { composeWithDevTools } from 'redux-devtools-extension'
import thunkMiddleware from 'redux-thunk'
import { globalReducer } from 'store/global/global.reducer'
import { modalReducer } from 'store/modal/modal.reducer'
import { ChallengeActionTypes } from './challenge/challenge.actions'
import { challengeReducer } from './challenge/challenge.reducer'
import { ChartActionTypes } from './chart/chart.actions'
import { chartReducer } from './chart/chart.reducer'
import { GlobalActionTypes } from './global/global.actions'
import { ModalActionTypes } from './modal/modal.actions'
import { ProfileActionTypes } from './profile/profile.actions'
import { profileReducer } from './profile/profile.reducer'
import { ProfileEcogestureActionTypes } from './profileEcogesture/profileEcogesture.actions'
import { profileEcogestureReducer } from './profileEcogesture/profileEcogesture.reducer'
import { ProfileTypeActionTypes } from './profileType/profileType.actions'
import { profileTypeReducer } from './profileType/profileType.reducer'

export interface EcolyoState {
  challenge: ChallengeState
  chart: ChartState
  global: GlobalState
  modal: ModalState
  profile: Profile
  profileEcogesture: ProfileEcogesture
  profileType: ProfileType
}

export const defaultAction = { type: null, payload: undefined }

const ecolyoReducer = combineReducers({
  challenge: challengeReducer,
  chart: chartReducer,
  global: globalReducer,
  modal: modalReducer,
  profile: profileReducer,
  profileEcogesture: profileEcogestureReducer,
  profileType: profileTypeReducer,
})

export interface AppStore {
  ecolyo: EcolyoState
  cozy: unknown
}

export type AppActionsTypes =
  | ChallengeActionTypes
  | ChartActionTypes
  | GlobalActionTypes
  | ModalActionTypes
  | ProfileActionTypes
  | ProfileEcogestureActionTypes
  | ProfileTypeActionTypes

const sentryReduxEnhancer = Sentry.createReduxEnhancer({})

const configureStore = (client: Client, persistedState: any) => {
  const middlewares = [thunkMiddleware.withExtraArgument({ client })]
  const composeEnhancers = composeWithDevTools({ trace: true }) || compose

  const store: Store<AppStore, AppActionsTypes> = createStore(
    combineReducers({
      ecolyo: ecolyoReducer,
      cozy: client.reducer(),
      persistedState,
    }),
    composeEnhancers(
      // eslint-disable-next-line prefer-spread
      applyMiddleware.apply(null, middlewares),
      sentryReduxEnhancer
    )
  )
  return store
}
export default configureStore
