import { ModalState } from 'models'
import { defaultAction } from 'store'
import { mockInitialModalState } from '../../../tests/__mocks__/store'
import { OPEN_FEEDBACK_MODAL, OPEN_PARTNERS_MODAL } from './modal.actions'
import { modalReducer } from './modal.reducer'

describe('modal reducer', () => {
  it('should return the initial state', () => {
    const state = modalReducer(undefined, { ...defaultAction })
    expect(state).toEqual(mockInitialModalState)
  })

  describe('Feedback Modal', () => {
    it('should handle UPDATE_FEEDBACK_MODAL with payload', () => {
      const state = modalReducer(mockInitialModalState, {
        type: OPEN_FEEDBACK_MODAL,
        payload: true,
      })
      expect(state).toEqual({
        ...mockInitialModalState,
        isFeedbacksOpen: true,
      })
    })
    it('should handle UPDATE_FEEDBACK_MODAL without payload', () => {
      const state = modalReducer(mockInitialModalState, {
        type: OPEN_FEEDBACK_MODAL,
      })
      expect(state).toEqual(mockInitialModalState)
    })
  })

  describe('PartnersInfo', () => {
    const partnersModalAllTrue = {
      egl: true,
      enedis: true,
      grdf: true,
    }
    it('should have all partners to false by default', () => {
      const state = modalReducer(mockInitialModalState, { ...defaultAction })
      const expectedResult: ModalState = {
        ...mockInitialModalState,
        partnersIssueModal: {
          egl: false,
          enedis: false,
          grdf: false,
        },
      }
      expect(state).toEqual(expectedResult)
    })
    it('should handle OPEN_PARTNERS_MODAL to set all partners to true', () => {
      const state = modalReducer(mockInitialModalState, {
        type: OPEN_PARTNERS_MODAL,
        payload: { ...partnersModalAllTrue },
      })
      const expectedResult: ModalState = {
        ...mockInitialModalState,
        partnersIssueModal: {
          ...partnersModalAllTrue,
        },
      }
      expect(state).toEqual(expectedResult)
    })
    it('should handle OPEN_PARTNERS_MODAL to set some partners to false', () => {
      const state = modalReducer(
        {
          ...mockInitialModalState,
          partnersIssueModal: {
            ...partnersModalAllTrue,
          },
        },
        {
          type: OPEN_PARTNERS_MODAL,
          payload: { egl: true, enedis: false, grdf: false },
        }
      )
      const expectedResult: ModalState = {
        ...mockInitialModalState,
        partnersIssueModal: {
          egl: true,
          enedis: false,
          grdf: false,
        },
      }
      expect(state).toEqual(expectedResult)
    })
  })
})
