import { profileData } from '../../../tests/__mocks__/profileData.mock'
import { createMockEcolyoStore } from '../../../tests/__mocks__/store'
import { updateProfile, UPDATE_PROFILE } from './profile.actions'

const mockUpdateProfile = jest.fn()
jest.mock('services/profile.service', () => {
  return jest.fn(() => {
    return {
      updateProfile: mockUpdateProfile,
    }
  })
})

describe('profile actions', () => {
  const store = createMockEcolyoStore()
  beforeEach(() => {
    store.clearActions()
  })
  it('should create an UPDATE_PROFILE action when profile is updated', async () => {
    mockUpdateProfile.mockResolvedValueOnce(profileData)
    const expectedActions = [
      {
        type: UPDATE_PROFILE,
        payload: profileData,
      },
    ]
    await store.dispatch(updateProfile(profileData))
    expect(store.getActions()).toEqual(expectedActions)
  })

  it('should not create action when profile is not updated', async () => {
    mockUpdateProfile.mockResolvedValueOnce(null)
    await store.dispatch(updateProfile(profileData))
    expect(store.getActions()).toEqual([])
  })
})
