import { Client } from 'cozy-client'
import { PROFILETYPE_DOCTYPE } from 'doctypes'
import { ProfileType } from 'models'
import { Dispatch } from 'react'
import ProfileTypeEntityService from 'services/profileTypeEntity.service'
import { AppStore, defaultAction } from 'store'

export const UPDATE_PROFILETYPE = 'UPDATE_PROFILETYPE'
export const CREATE_NEW_PROFILETYPE = 'CREATE_NEW_PROFILETYPE'

export interface UpdateProfileType {
  type: typeof UPDATE_PROFILETYPE
  payload?: ProfileType
}

export interface CreateNewProfileType {
  type: typeof CREATE_NEW_PROFILETYPE
  payload?: ProfileType
}

export type ProfileTypeActionTypes =
  | UpdateProfileType
  | CreateNewProfileType
  | typeof defaultAction

export function updateProfileTypeSuccess(
  updatedProfileType: ProfileType
): UpdateProfileType {
  return {
    type: UPDATE_PROFILETYPE,
    payload: updatedProfileType,
  }
}

export function updateProfileType(updates: Partial<ProfileType>): any {
  return async (
    dispatch: Dispatch<UpdateProfileType>,
    getState: () => AppStore,
    { client }: { client: Client }
  ): Promise<void> => {
    const profileTypeEntityService = new ProfileTypeEntityService(client)
    const updatedProfileType = await profileTypeEntityService.updateProfileType(
      updates
    )
    if (updatedProfileType) {
      dispatch(updateProfileTypeSuccess(updatedProfileType))
    }
  }
}

export function newProfileTypeEntry(updates: Partial<ProfileType>): any {
  return async (
    dispatch: Dispatch<UpdateProfileType>,
    getState: () => AppStore,
    { client }: { client: Client }
  ) => {
    const { data: newProfileType } = await client.create(
      PROFILETYPE_DOCTYPE,
      updates
    )
    if (newProfileType) {
      dispatch(updateProfileTypeSuccess(newProfileType))
    }
  }
}
